/*
 *	ASCVersion.h
 *	Blocks
 *
 *	© Copyright 2007 Apokalypse Software Corp.. All Rights Reserved Worldwide.
 *
 *	Date		Username		Activity
 *	----------	------------	-----------
 *	2007-12-26	huperniketes	Created to store the class developed in BKSoftwareUpdateController.m.
 *	2007-12-29	huperniketes	-ASCVersion::initWithProjectVersionString: -	Added to handle ASC Project Version Format (MMmmb.bs.rr).
 *	2007-12-30	huperniketes	ASCVersion -									Changed result types of segment methods from unsigned int to int to provide mechanism for error values.
 *								+ASCVersion::versionWithProjectVersionString: -	Added to handle ASC Project Version Format (MMmmb.bs.rr).
 *	2008-01-01	huperniketes	ASCVersion										Some braces around instance var declarations are occasionally nice.
 */
#import <Cocoa/Cocoa.h>

#define		ASCVERSION_USES_PROJECT_VERSION_FORMAT	(1)

@interface	ASCVersion : NSNumber
{
	// Marketing Version Format MM.mm.bb s rr
	// MMMMMMmm mmmmbbbb bbbssssr rrrrrrrr

	int				vMajorSegment;
	int				vMinorSegment;
	int				vMaintenanceSegment;
	int				vStageSegment;
	int				vBuildSegment;
}

+ (ASCVersion *)versionNormalizedByAppWithString: (NSString *)aString;
+ (ASCVersion *)versionWithGestaltVersionNumber: (unsigned int)aVersionNumber;
+ (ASCVersion *)versionWithString: (NSString *)aString;
+ (ASCVersion *)versionWithProjectVersionString: (NSString *)aString;
+ (ASCVersion *)versionWithPrettyUnsignedInt: (unsigned int)aVersionValue;
+ (ASCVersion *)versionWithUnsignedInt: (unsigned int)aVersionValue;

- (ASCVersion *)initWithGestaltVersionNumber: (SInt32)aVersionNumber;
- (ASCVersion *)initWithString: (NSString *)aString;
- (ASCVersion *)initWithProjectVersionString: (NSString *)aString;
- (ASCVersion *)initWithPrettyUnsignedInt: (unsigned int)aVersionValue;
- (ASCVersion *)initWithUnsignedInt: (unsigned int)aVersionValue;

- (int)majorValue;
- (int)minorValue;
- (int)maintenanceValue;
- (int)stageValue;
- (int)buildValue;
- (unsigned int)prettyUnsignedIntValue;
- (unsigned int)unsignedIntValue;

- (NSNumber *)unsignedIntNumber;
- (NSNumber *)prettyUnsignedIntNumber;

#define	kASCVersionStageDevelopment	(0)
#define	kASCVersionStageAlpha		(1)
#define	kASCVersionStageBeta		(2)
#define	kASCVersionStageRelease		(9)

@end

@interface NSApplication (NSApplication_ASCVersionExtensions)

- (ASCVersion *)applicationMinimumOSVersion;
- (ASCVersion *)applicationNormalizedVersion: (NSString *)aVersionString;

@end
